@@ -11,14 +11,14 @@ the args that were emitted.
 from __future__ import annotations
 
 import warnings
+from dataclasses import dataclass
 from types import MappingProxyType
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     ClassVar,
     Literal,
-    NamedTuple,
+    SupportsIndex,
     overload,
 )
 
@@ -28,7 +28,14 @@ from ._mypyc import mypyc_attr
 
 if TYPE_CHECKING:
     import threading
-    from collections.abc import Container, Iterable, Iterator, Mapping
+    from collections.abc import (
+        Callable,
+        Container,
+        Hashable,
+        Iterable,
+        Iterator,
+        Mapping,
+    )
     from contextlib import AbstractContextManager
 
     from psygnal._signal import F, ReducerFunc
@@ -37,17 +44,96 @@ if TYPE_CHECKING:
 __all__ = ["EmissionInfo", "SignalGroup"]
 
 
-class EmissionInfo(NamedTuple):
+@dataclass(slots=True, frozen=True)
+class PathStep:
+    """A single step in a path to a nested signal.
+
+    This is used to represent a path to a signal that is nested inside an object,
+    such as when a signal is emitted from a nested object or a list.  The
+    `EmissionInfo.path` is a tuple of `PathStep` objects, where each `PathStep`
+    represents either:
+
+    - an _attribute_ access (e.g. `.foo`)
+    - an _index_ access (e.g. `[3]`)
+    - a _key_ access (e.g. `['user']`)
+
+    !!! note
+        _yes, `index` and `key` both just get passed to `__getitem__` in the end, but we
+        differentiate them here to make it clearer whether the step is a key in a
+        `Mapping` or an index in a `Sequence`._
+    """
+
+    attr: str | None = None
+    index: SupportsIndex | None = None
+    key: Hashable | None = None
+
+    def __post_init__(self) -> None:
+        # enforce mutual exclusivity
+        if sum(x is not None for x in (self.attr, self.index, self.key)) != 1:
+            raise ValueError(
+                "PathStep must have exactly one of attr, index, or key set."
+            )
+
+    # nice debug display: .foo, [3], ['user']
+    def __repr__(self) -> str:  # pragma: no cover
+        if self.attr is not None:
+            return f".{self.attr}"
+
+        if self.index is not None:
+            return f"[{int(self.index)}]"
+
+        key = repr(self.key)
+        if len(key) > 20 and not isinstance(self.key, str):
+            key = f"{key[:17]}..."
+        return f"[{key}]"
+
+
+@dataclass(slots=True, frozen=True)
+class EmissionInfo:
     """Tuple containing information about an emission event.
 
     Attributes
     ----------
     signal : SignalInstance
+        The SignalInstance doing the emitting
     args: tuple
+        The args that were emitted
+    path: tuple[PathStep, ...]
+        A tuple of PathStep objects that describe the path to the signal that was
+        emitted. This is useful for nested signals, where the path can be used to
+        determine the hierarchy of the signals.  For example, if a signal is emitted
+        from a nested object like `bar.foo[3]['user']`, the path will contain the steps
+        to get to that object, such as (PathStep(attr='foo'), PathStep(index=3),
+        PathStep(key='user')).
     """
 
     signal: SignalInstance
     args: tuple[Any, ...]
+    path: tuple[PathStep, ...] = ()
+
+    def insert_path(self, *path: PathStep) -> EmissionInfo:
+        """Return a new EmissionInfo with the given path steps inserted at the front."""
+        return EmissionInfo(self.signal, self.args, (*path, *self.path))
+
+    def __post_init__(self) -> None:
+        if self.path and not all(
+            isinstance(p, (PathStep, str, int)) for p in self.path
+        ):
+            raise TypeError(
+                "EmissionInfo.path must be a tuple of PathStep objects, "
+                "or a tuple of str or int."
+            )
+
+    def __iter__(self) -> Iterator[Any]:  # pragma: no cover
+        """Iterate over the EmissionInfo and all nested EmissionInfos."""
+        warnings.warn(
+            "`EmissionInfo.__iter__` is no longer a NamedTuple and should not be "
+            "iterated over.  Use direct attribute access instead.",
+            RuntimeWarning,
+            stacklevel=2,
+        )
+        yield self.signal
+        yield self.args
 
 
 class SignalRelay(SignalInstance):
@@ -70,6 +156,7 @@ class SignalRelay(SignalInstance):
         super().__init__(signature=(EmissionInfo,), instance=instance)
         self._signals = MappingProxyType(signals)
         self._sig_was_blocked: dict[str, bool] = {}
+        self._on_first_connect_callbacks: list[Callable[[], None]] = []
 
     def _append_slot(self, slot: WeakCallback) -> None:
         super()._append_slot(slot)
@@ -77,6 +164,10 @@ class SignalRelay(SignalInstance):
             self._connect_relay()
 
     def _connect_relay(self) -> None:
+        # Call any registered callbacks on first connection
+        for callback in self._on_first_connect_callbacks:
+            callback()
+
         # silence any warnings about failed weakrefs (will occur in compiled version)
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
@@ -94,10 +185,32 @@ class SignalRelay(SignalInstance):
         for sig in self._signals.values():
             sig.disconnect(self._slot_relay)
 
-    def _slot_relay(self, *args: Any) -> None:
-        if emitter := Signal.current_emitter():
-            info = EmissionInfo(emitter, args)
-            self._run_emit_loop((info,))
+    def _slot_relay(self, *args: Any, loc: PathStep | None = None) -> None:
+        """Relay signals from child to parent.
+
+        This is an important method for SignalGroups.  It is the method that is
+        responsible for relaying signals from all child signals within the group
+        to any connected slots on the group itself.
+        """
+        emitter = Signal.current_emitter()
+        if emitter is None:
+            return
+
+        par_path = (loc,) if loc is not None else ()
+        # If child already gave us an EmissionInfo, use it;
+        if args and isinstance((info := args[0]), EmissionInfo):
+            child_info = info.insert_path(*par_path)
+        # else wrap its args unchanged
+        else:
+            child_info = emitter._psygnal_relocate_info_(
+                EmissionInfo(signal=emitter, args=args, path=par_path)
+            )
+
+        self._run_emit_loop((child_info,))
+
+    def _relay_partial(self, loc: PathStep | None) -> _relay_partial:
+        """Return special partial that will call _slot_relay with 'loc'."""
+        return _relay_partial(self, loc)
 
     def connect_direct(
         self,
@@ -105,7 +218,7 @@ class SignalRelay(SignalInstance):
         *,
         check_nargs: bool | None = None,
         check_types: bool | None = None,
-        unique: bool | str = False,
+        unique: bool | Literal["raise"] = False,
         max_args: int | None = None,
     ) -> Callable[[Callable], Callable] | Callable:
         """Connect `slot` to be called whenever *any* Signal in this group is emitted.
@@ -126,7 +239,7 @@ class SignalRelay(SignalInstance):
             If `True`, An additional check will be performed to make sure that types
             declared in the slot signature are compatible with the signature
             declared by this signal, by default `False`.
-        unique : bool | str
+        unique : bool | Literal["raise"]
             If `True`, returns without connecting if the slot has already been
             connected.  If the literal string "raise" is passed to `unique`, then a
             `ValueError` will be raised if the slot is already connected.
@@ -205,6 +318,44 @@ class SignalRelay(SignalInstance):
             sig.disconnect(slot, missing_ok)
         super().disconnect(slot, missing_ok)
 
+    def _slot_index(self, slot: Callable) -> int:
+        """Get index of `slot` in `self._slots`. Return -1 if not connected.
+
+        In interpreted mode, `_relay_partial` callbacks are stored as
+        weak references to the callable object itself, so comparing the
+        dereferenced callback to the provided `_relay_partial` works. In compiled
+        mode (mypyc), `weak_callback` may normalize a `_relay_partial` to a strong
+        reference to its `__call__` method (a MethodWrapperType), to avoid segfaults on
+        garbage collection. In that case the default WeakCallback equality logic is the
+        correct and more robust path.
+
+        Therefore, try the base implementation first (which compares normalized
+        WeakCallback objects). If that fails and we're dealing with a
+        `_relay_partial`, fall back to comparing the dereferenced callable to the
+        provided slot for backward compatibility.
+        """
+        # First, try the standard equality path used by SignalInstance
+        idx = super()._slot_index(slot)
+        if idx != -1:
+            return idx
+
+        # Fallback: handle direct comparison for `_relay_partial` instances
+        if isinstance(slot, _relay_partial):
+            with self._lock:
+                for i, s in enumerate(self._slots):
+                    deref = s.dereference()
+                    # Case 1: stored deref is the _relay_partial itself (interpreted)
+                    if deref == slot:
+                        return i
+                    # Case 2: compiled path where we stored __call__ bound method
+                    # (these will never hit on codecov, but they are covered in tests)
+                    owner = getattr(deref, "__self__", None)  # pragma: no cover
+                    if (
+                        isinstance(owner, _relay_partial) and owner == slot
+                    ):  # pragma: no cover
+                        return i
+        return -1  # pragma: no cover
+
 
 # NOTE
 # To developers. Avoid adding public names to this class, as it is intended to be
@@ -340,6 +491,11 @@ class SignalGroup:
             )
         super().__init_subclass__()
 
+    @property
+    def instance(self) -> Any:
+        """Object that owns this `SignalGroup`."""
+        return self._psygnal_relay.instance
+
     @property
     def all(self) -> SignalRelay:
         """SignalInstance that can be used to connect to all signals in this group.
@@ -383,16 +539,6 @@ class SignalGroup:
         """Get a signal instance by name."""
         return self._psygnal_instances[item]
 
-    # this is just here for type checking, particularly on cases
-    # where the SignalGroup comes from the SignalGroupDescriptor
-    # (such as in evented dataclasses).  In those cases, it's hard to indicate
-    # to mypy that all remaining attributes are SignalInstances.
-    def __getattr__(self, __name: str) -> SignalInstance:
-        """Get a signal instance by name."""
-        raise AttributeError(  # pragma: no cover
-            f"{type(self).__name__!r} object has no attribute {__name!r}"
-        )
-
     def __iter__(self) -> Iterator[str]:
         """Yield the names of all signals in the group."""
         return iter(self._psygnal_instances)
@@ -406,7 +552,13 @@ class SignalGroup:
     def __repr__(self) -> str:
         """Return repr(self)."""
         name = self.__class__.__name__
-        return f"<SignalGroup {name!r} with {len(self)} signals>"
+
+        if self.instance is not None:
+            owner_type = type(self.instance).__name__
+            owner_repr = f" on <{owner_type} instance at {id(self.instance):#x}>"
+        else:
+            owner_repr = ""
+        return f"<SignalGroup {name!r}{owner_repr} with {len(self)} signals>"
 
     @classmethod
     def psygnals_uniform(cls) -> bool:
@@ -442,7 +594,7 @@ class SignalGroup:
         thread: threading.Thread | Literal["main", "current"] | None = ...,
         check_nargs: bool | None = ...,
         check_types: bool | None = ...,
-        unique: bool | str = ...,
+        unique: bool | Literal["raise"] = ...,
         max_args: int | None = None,
         on_ref_error: RefErrorChoice = ...,
         priority: int = ...,
@@ -456,7 +608,7 @@ class SignalGroup:
         thread: threading.Thread | Literal["main", "current"] | None = ...,
         check_nargs: bool | None = ...,
         check_types: bool | None = ...,
-        unique: bool | str = ...,
+        unique: bool | Literal["raise"] = ...,
         max_args: int | None = None,
         on_ref_error: RefErrorChoice = ...,
         priority: int = ...,
@@ -469,10 +621,11 @@ class SignalGroup:
         thread: threading.Thread | Literal["main", "current"] | None = None,
         check_nargs: bool | None = None,
         check_types: bool | None = None,
-        unique: bool | str = False,
+        unique: bool | Literal["raise"] = False,
         max_args: int | None = None,
         on_ref_error: RefErrorChoice = "warn",
         priority: int = 0,
+        emit_on_evented_child_events: bool = False,
     ) -> Callable[[F], F] | F:
         if slot is None:
             return self._psygnal_relay.connect(
@@ -483,6 +636,7 @@ class SignalGroup:
                 max_args=max_args,
                 on_ref_error=on_ref_error,
                 priority=priority,
+                emit_on_evented_child_events=emit_on_evented_child_events,
             )
         else:
             return self._psygnal_relay.connect(
@@ -494,6 +648,7 @@ class SignalGroup:
                 max_args=max_args,
                 on_ref_error=on_ref_error,
                 priority=priority,
+                emit_on_evented_child_events=emit_on_evented_child_events,
             )
 
     def connect_direct(
@@ -502,7 +657,7 @@ class SignalGroup:
         *,
         check_nargs: bool | None = None,
         check_types: bool | None = None,
-        unique: bool | str = False,
+        unique: bool | Literal["raise"] = False,
         max_args: int | None = None,
     ) -> Callable[[Callable], Callable] | Callable:
         return self._psygnal_relay.connect_direct(
@@ -548,3 +703,32 @@ def _is_uniform(signals: Iterable[Signal]) -> bool:
             return False
         seen.add(v)
     return True
+
+
+class _relay_partial:
+    """Small, single-purpose, mypyc-friendly variant of functools.partial.
+
+    Used to call SignalRelay._slot_relay with a specific loc.
+    __hash__ and __eq__ are implemented to make this object hashable and
+    comparable to other _relay_partial objects, so that adding it to a set
+    twice will not create two separate entries.
+    """
+
+    __slots__ = ("loc", "relay")
+
+    def __init__(self, relay: SignalRelay, loc: PathStep | None = None) -> None:
+        self.relay = relay
+        self.loc = loc
+
+    def __call__(self, *args: Any) -> Any:
+        return self.relay._slot_relay(*args, loc=self.loc)
+
+    def __hash__(self) -> int:
+        return hash((self.relay, self.loc))
+
+    def __eq__(self, other: Any) -> bool:
+        return (
+            isinstance(other, _relay_partial)
+            and self.relay == other.relay
+            and self.loc == other.loc
+        )
